@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,6 +29,7 @@ namespace Ui {
     class PrintQueueUi;
 }
 
+class KCupsRequest;
 class KCupsPrinter;
 class JobSortFilterModel;
 class JobModel;
@@ -46,7 +47,7 @@ public slots:
     void update();
 
 private slots:
-    void updatePrinter(const QString &printer);
+    void updatePrinterByName(const QString &printer);
     void updatePrinter(const QString &text,
                        const QString &printerUri,
                        const QString &printerName,
@@ -66,7 +67,7 @@ private slots:
     void updateButtons();
     void showContextMenu(const QPoint &point);
     void showHeaderContextMenu(const QPoint &point);
-    void getAttributesFinished();
+    void getAttributesFinished(KCupsRequest *request);
 
 private:
     void closeEvent(QCloseEvent *event) Q_DECL_OVERRIDE;
@@ -80,14 +81,14 @@ private:
     JobModel *m_model;
     QString m_destName;
     QString m_title;
-    bool m_isClass;
-    bool m_preparingMenu;
     QPixmap m_printerIcon;
     QPixmap m_pauseIcon;
     QPixmap m_startIcon;
     QPixmap m_warningIcon;
-    bool m_printerPaused;
-    char m_lastState;
+    char m_lastState = 0;
+    bool m_isClass;
+    bool m_preparingMenu = false;
+    bool m_printerPaused = false;
 };
 
 #endif
